#
# spec file for package dnglab
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Atri Bhattacharya <badshah400@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dnglab
Version:        0.7.0
Release:        1.1
Summary:        Camera RAW to DNG file format converter
License:        LGPL-2.1-only
URL:            https://github.com/dnglab/dnglab
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
# PATCH-FEATURE-OPENSUSE dnglab-renamed-exec-usage-msg.patch badshah400@gmail.com -- Adapt usage message to renamed binary
Patch0:         dnglab-renamed-exec-usage-msg.patch
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  rust >= 1.79

%description
%{name} provides a command line tool to convert camera RAW files to Digital
Negative Format (DNG).

%package bash-completion
Summary:        This package provides tab completion for dnglab on the bash shell
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
%{name} provides a command line tool to convert camera RAW files to Digital
Negative Format (DNG).

This package provides tab completion for %{name} on the bash shell.

%package fish-completion
Summary:        This package provides tab completion for dnglab on the fish shell
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
%{name} provides a command line tool to convert camera RAW files to Digital
Negative Format (DNG).

This package provides tab completion for %{name} on the fish shell.

%prep
%autosetup -p1 -a1

%build
%{cargo_build} --all

%install
%{cargo_install -p bin/dnglab}
%{cargo_install -p rawler}

# Shell completions
## Bash
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
cp ./bin/dnglab/completions/{_dnglab,dnglab.bash} %{buildroot}%{_datadir}/bash-completion/completions/
## Fish
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
cp ./bin/dnglab/completions/dnglab.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/

# Man files
mkdir -p %{buildroot}%{_mandir}/man1
cp ./bin/dnglab/manpages/*.1 %{buildroot}%{_mandir}/man1/

# Rename generic binary names to avoid current and future file-naming conflicts
mv %{buildroot}%{_bindir}/benchmark %{buildroot}%{_bindir}/%{name}-benchmark
mv %{buildroot}%{_bindir}/identify %{buildroot}%{_bindir}/%{name}-identify

%check
%{cargo_test}

%files
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-benchmark
%{_bindir}/%{name}-identify
%{_mandir}/man1/*.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/*

%files fish-completion
%{_datadir}/fish/

%changelog
* Sun Jun  8 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.0:
  * Update to image-rs 0.25 (gh#dnglab/dnglab#479).
  * Add RawDecodeParams to Decoder::full_image()
    (gh#dnglab/dnglab#481).
  * Fix: Use same version for dnglab and dnglab-lib and provide
    test case (gh#dnglab/dnglab#486).
  * Cleanup compiler warnings and hints in newer Rust versions
    (gh#dnglab/dnglab#490).
  * Add Kodak RADC decompressor (gh#dnglab/dnglab#491).
  * QTK support for Apple QuickTake 100 and 150
    (gh#dnglab/dnglab#492).
  * Add support for Kodak DC50 (gh#dnglab/dnglab#493).
  * Show warning if lens is not found in lens database
    (gh#dnglab/dnglab#495).
  * Add DecoderCache for simple caching of data based on
    RawDecodeParams (gh#dnglab/dnglab#496).
  * Bump anstream from 0.6.5 to 0.6.15 (gh#dnglab/dnglab#489).
  * Support for Canon RF 200-800mm F6.3-9 IS USM
    (gh#dnglab/dnglab#497).
  * Bump mio from 0.8.10 to 0.8.11 (gh#dnglab/dnglab#410).
  * Update env_logger requirement from 0.9 to 0.11 in /rawler
    (gh#dnglab/dnglab#399).
  * Change RawFile to RawSource and add support for mmap() input
    (gh#dnglab/dnglab#416).
  * Add support for Canon RF-S 10-18mm F4.5-6.3 IS STM
    (gh#dnglab/dnglab#508).
  * Fix clean model name for EOS R5 Mark II
    (gh#dnglab/dnglab#510).
  * Fix: EXIF TimezoneOffset must be a vector because it contains
    two values (gh#dnglab/dnglab#512).
  * Fix: Use canonical address in FTP client address handling
    (gh#dnglab/dnglab#513).
  * Add --keep-mtime flag (gh#dnglab/dnglab#511).
  * Update to multiversion 0.8 (gh#dnglab/dnglab#516).
  * Update to Rust Edition 2024 (gh#dnglab/dnglab#517).
  * Add fixed lens support (gh#dnglab/dnglab#518).
  * Fix PhaseOne IIQ blacklevel correction (gh#dnglab/dnglab#519).
  * Add Phase One P25 alias (gh#dnglab/dnglab#520).
  * Phase One P45 support (gh#dnglab/dnglab#521).
  * Add Sony UMC R10C Support (gh#dnglab/dnglab#522).
  * Add hint to CONTRIBUTE_SAMPLES.md for unsupported files
    (gh#dnglab/dnglab#523).
  * Improve hint when camera raw file is unsupported
    (gh#dnglab/dnglab#524).
  * Bump tokio from 1.43.0 to 1.43.1 (gh#dnglab/dnglab#532).
  * Support for Panasonic DC-S9 (gh#dnglab/dnglab#536).
  * Fujifilm X-M5 support (gh#dnglab/dnglab#538).
  * Update completions and manpages (gh#dnglab/dnglab#542).
  * Nikon Z 50 II support (gh#dnglab/dnglab#543).
  * Use SONYRAWIMAGESIZE EXIF tag for ARW files
    (gh#dnglab/dnglab#544).
  * Update E-Mount lens database (gh#dnglab/dnglab#545).
- Minor rebase of dnglab-renamed-exec-usage-msg.patch for update.
* Mon Feb  3 2025 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add dnglab-renamed-exec-usage-msg.patch: Adapt usage message to
  renamed binary.
